@@ -639,9 +639,11 @@ class BaseExperiment:
         metadata_dir = f"{self.log_path}/jsonlogs/{model.__class__.__name__}/{model_metadata}"
         self._create_folder(metadata_dir)
         jsonlog_version = len(os.listdir(metadata_dir))
-        
-        # saving results 
-        self._create_folder(f"{metadata_dir}/version_{jsonlog_version}")
+        model_metadata = self.set_model_metadata(model, self.get_hparams(model))
+        jsonlog_folder = f"{metadata_dir}/version_{jsonlog_version}"
+        self._create_folder(jsonlog_folder) # necessary for sklearn-based models
+        jsonlog_path = f"{jsonlog_folder}/validation_metrics.json"
+        # saving results
         if isinstance(model, BaseEstimator):
             tensorboard_logdir = self.logger.get_logdir()
         else:
@@ -653,7 +655,7 @@ class BaseExperiment:
             self.saved_model_types.update({model.__class__: 1})
         
         self.n_ckpts += 1 
-        self.log_metrics_to_json(model, tensorboard_logdir, jsonlog_version, val_metrics)
+        self.log_metrics_to_json(model, tensorboard_logdir, jsonlog_path, val_metrics)
         self.update_exp_metadata()
     
     def save_to_stack(self)->None:
@@ -939,7 +941,7 @@ class BaseExperiment:
         hparams_str = self._dict_to_str(hparams)
         hparams_str = "default_hyperparameters" if hparams_str == "" else hparams_str
         
-        model_metadata = model.__class__.__name__ + "-" + hparams_str 
+        model_metadata = f"{model.__class__.__name__}-{hparams_str}" 
 
         #################################################
         # Shorten the length of model_metadata
@@ -960,7 +962,7 @@ class BaseExperiment:
                 add_ = str(value).replace(".","d") + "-"
                 truncated_hparams_str += add_
             
-            new_metadata = model.__class__.__name__ + truncated_hparams_str   
+            new_metadata = f"{model.__class__.__name__}-{truncated_hparams_str}"   
             if len(new_metadata) > length_limit:
                 logger.info(f"The length of the metadata is too long due to long hyperparameter specs. \
                     We will take the first {length_limit-subtract} letters from the hyperparameter part.")
@@ -983,7 +985,7 @@ class BaseExperiment:
         self, 
         model : Union["pl.LightningModule", "BaseEstimator"],
         tensorboard_logdir: str,
-        version : int,
+        jsonlog_path : str,
         metrics_dict : Optional[dict] = None
     )->None:
         r"""Save results as a json file.
@@ -994,7 +996,7 @@ class BaseExperiment:
 
             tensorboard_logdir (str): location of the TensorBoard logs.
 
-            version (int): The version of the model. >0 when identical models are trained and logged.
+            jsonlog_path (str): The path where the validation results are going to be saved.
 
             metrics_dict (dict, optional): Results to save as a json file. If None, the results in the TensorBoard will be saved.
                 Default: ``None``
@@ -1007,11 +1009,6 @@ class BaseExperiment:
         error_count = 0
         self.update_log_path()
 
-        model_metadata = self.set_model_metadata(model, self.get_hparams(model))
-        jsonlog_folder = f"{self.log_path}/jsonlogs/{model.__class__.__name__}/{model_metadata}/version_{version}"
-        self._create_folder(jsonlog_folder) # necessary for sklearn-based models
-        jsonlog_path = f"{jsonlog_folder}/validation_metrics.json"
-
         if not metrics_dict:
             event = EventAccumulator(tensorboard_logdir)
             event.Reload()
