@@ -11,41 +11,40 @@ import math
 import numpy as np
 
 
-# *****************************************************************  Classes  ***************************************************************** 
-########################################################## _MLP & MLP (Begins) ##########################################################
-"""
-_MLP and MLP defines an MLP with all hidden layers having a same number of hidden units.
-Therefore, the hyperparameters that are additionally defined in MLP are n_layers and n_hidden_units.
 
-_MLP and MLP are basically identical in structure. The only difference is that _MLP is an offspring
-of nn.Module and MLP is an offspring of BaseNet.
-
-Arguments:
-    - dims (Union[int, Tuple[int]]): The dimension of the data. e.g., 4, (8,8,1)
-
-    - n_classes (Optional[int]) : Number of classes (labels) in the classification task.
-                                    Do not specify this argument (set is as None) when you 
-                                    are performing regression tasks.
-    
-    - n_layers (int) : Number of layers. If 1, it would be an old-school perceptron i.e., logistic regression.
-                       Default : 2
-
-    - n_hidden_units (int) : Number of hidden units for all hidden layers. Default : 10 
-
-    - batch_size (int) : Batch size. Default : 64 (see utils_lightning.py)
-
-    - optimizer_type (str) : Type of the optimizer. ("adam" or "sgd") Default : "adam" (see utils_lightning.py) 
-                            #TODO : implement other optimizers.(in model_base.py)
-
-    - dropout_p (0<= float < 1) : Dropout probability Default : 0 (see utils_lightning.py)
-
-    - bn (bool) : Whether to use batch normalization or not. Default : True (see utils_lightning.py)
-
-    - weight_decay (0<= float) : coefficient for L2-regularization. Default : 0 (see utils_lightning.py)
-
-    - lr ( 0 < float) : Learning rate. Default: 1e-4 (see utils_lightning.py)
-"""
 class _MLP(nn.Module):
+    r"""Multilayer perceptron with identical # of hidden units.
+
+    Args:
+
+        dims (int or tuple of int): The dimension of the data. e.g., 4, (8,8,1)
+
+        n_classes (int, optional): Number of classes (labels) in the classification task.
+        
+        n_layers (int): Number of layers. If 1, it would be an old-school perceptron i.e., logistic regression.
+            Default: ``2``
+
+        n_hidden_units (int): Number of hidden units for all hidden layers. 
+            Default : ``10`` 
+
+        batch_size (int): Batch size. 
+            Default : ``64``
+
+        optimizer_type (str): Type of the optimizer. ("adam" or "sgd") 
+            Default : ``"adam"`` 
+
+        dropout_p (float): Dropout probability 
+            Default : ``0``
+
+        bn (bool): Whether to use batch normalization or not. 
+            Default : ``True``
+
+        weight_decay (float): Coefficient for L2-regularization. 
+            Default : ``0`` 
+
+        lr (float): Learning rate. 
+            Default: ``1e-4``
+    """
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
